@@ -1,5 +1,7 @@
 package CPANPLUS::Dist::Build::Constants;
 
+use if $] > 5.017, 'deprecate';
+
 use strict;
 use warnings;
 use File::Spec;
@@ -9,7 +11,7 @@ BEGIN {
     require Exporter;
     use vars    qw[$VERSION @ISA @EXPORT];
 
-    $VERSION    = '0.66';
+    $VERSION    = '0.72';
     @ISA        = qw[Exporter];
     @EXPORT     = qw[ BUILD_DIR BUILD CPDB_PERL_WRAPPER];
 }
@@ -31,7 +33,7 @@ use constant BUILD          => sub { my $file = @_
                             };
 
 
-use constant CPDB_PERL_WRAPPER   => 'use strict; BEGIN { my $old = select STDERR; $|++; select $old; $|++; $0 = shift(@ARGV); my $rv = do($0); die $@ if $@; die "$!" unless defined $rv; }';
+use constant CPDB_PERL_WRAPPER   => 'use strict; BEGIN { my $old = select STDERR; $|++; select $old; $|++; $0 = shift(@ARGV); my $rv = do($0); die $@ if $@; }';
 
 1;
 
